/*
 *  playlist.h
 *  mod_musicindex
 *
 *  $Id: playlist.h 566 2006-02-04 01:14:20Z boudinr $
 *
 *  Created by Thibaut VARENE on Thu Mar 20 2003.
 *  Copyright (c) 2003-2004 Regis BOUDIN
 *  Copyright (c) 2003-2004 Thibaut VARENE
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */

#ifndef PLAYLIST_H
#define PLAYLIST_H

#include "mod_musicindex.h"

/**
 * Function pointer type, as we need it.
 *
 * Here comes the declaration of the funny part... We will (again) use
 * function pointers which will allocate a new entry  from the apache pool,
 * fill it, and close the "in" file if they recognise the file.
 */
typedef mu_ent* (*make_entry_ptr)(request_rec *, apr_pool_t *, FILE *const, mu_ent *const,
				const mu_config *const, mu_ent_names *const);

/**
 * Enumerate handlers to access relevant data in struct filetype.
 * <b>BEWARE</b>: you must keep that in a coherent order wrt
 * struct filetype[] !
 * FT_MAX is the last element of the enum, it's a marker that gives
 * us the size of the corresponding array.
 */
enum { FT_MP3, FT_OGG, FT_FLAC, FT_MP4, FT_MAX };

/**
 * Array of common strings widely used.
 * Mind the above enum comment please.
 *
 * http://filext.com/detaillist.php?extdetail=M3U
 * http://filext.com/detaillist.php?extdetail=MP3
 * http://filext.com/detaillist.php?extdetail=OGG
 * http://filext.com/detaillist.php?extdetail=FLAC
 * http://filext.com/detaillist.php?extdetail=MP4
 *
 * XXX is currently declared static for obvious build reasons,
 * that needs to be fixed cleanly.
 */
static const struct {
	const char *const nametype;	/**< Display name of the filetype */
	const char *const mimetype;	/**< Mime type associated to the filetype */
} filetype[] = {
	{ "MP3", "audio/x-mp3" },
	{ "Vorbis", "audio/x-ogg" },
	{ "FLAC", "audio/flac" },
	{ "MP4/AAC", "audio/mp4" }
};

mu_ent *new_ent(apr_pool_t *pool);

mu_ent *make_music_entry(request_rec *r, apr_pool_t *pool,
	mu_ent *const head, mu_config *const conf, mu_ent_names *names);

mu_ent *build_custom_list(request_rec *r, mu_config *const conf);

#endif	/* PLAYLIST_H */
